<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_BE">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>MX Package Installer</source>
        <translation>MX Installateur de paquets - MX Package Installer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Applications populaires</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="420"/>
        <location filename="../mainwindow.ui" line="817"/>
        <location filename="../mainwindow.ui" line="1074"/>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Gérer les paquets populaires&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="190"/>
        <location filename="../mainwindow.ui" line="686"/>
        <location filename="../mainwindow.ui" line="1099"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.ui" line="699"/>
        <location filename="../mainwindow.ui" line="1167"/>
        <location filename="../mainwindow.ui" line="1431"/>
        <source>= Installed packages</source>
        <translation>= Paquets installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Enabled Repos</source>
        <translation>Dépôts activés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remove all the packages that are marked as &amp;quot;autoremovable&amp;quot;. If you want to manage them, select Autoremovable from drop-down selection box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Supprimer tous les paquets marqués comme &amp;quot;autoremovable ou autosupprimable&amp;quot;. Si vous souhaitez les gérer, sélectionnez « Autoremovable » ou « Autosupprimable » dans la liste déroulante.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Autoremove packages</source>
        <translation>Autosuppression des paquets</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="1324"/>
        <source>Upgrade All</source>
        <translation>Tout mettre à niveau</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.ui" line="926"/>
        <source>Installed:</source>
        <translation>Installés:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Total packages:</source>
        <translation>Total des paquets:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="987"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Installer également les paquets « recommandés »</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="577"/>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Upgradable:</source>
        <translation>Pouvant être mis à niveau:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.ui" line="584"/>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Hide library and developer packages</source>
        <translation>Masquer les paquets pour développeur et la bibliothèque</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.ui" line="633"/>
        <location filename="../mainwindow.ui" line="1006"/>
        <location filename="../mainwindow.ui" line="1524"/>
        <source>Refresh list</source>
        <translation>Rafraîchir la liste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <location filename="../mainwindow.ui" line="758"/>
        <location filename="../mainwindow.ui" line="1129"/>
        <location filename="../mainwindow.ui" line="1479"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrer les paquets selon leur état.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.ui" line="761"/>
        <location filename="../mainwindow.ui" line="765"/>
        <location filename="../mainwindow.ui" line="1132"/>
        <location filename="../mainwindow.ui" line="1136"/>
        <location filename="../mainwindow.cpp" line="3054"/>
        <source>All packages</source>
        <translation>Tous les paquets</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <location filename="../mainwindow.ui" line="770"/>
        <location filename="../mainwindow.ui" line="1141"/>
        <location filename="../mainwindow.cpp" line="3074"/>
        <source>Installed</source>
        <translation>Installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <location filename="../mainwindow.ui" line="775"/>
        <location filename="../mainwindow.ui" line="1146"/>
        <location filename="../mainwindow.cpp" line="3075"/>
        <source>Upgradable</source>
        <translation>Mise à niveau possible</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="503"/>
        <location filename="../mainwindow.ui" line="780"/>
        <location filename="../mainwindow.ui" line="1151"/>
        <location filename="../mainwindow.ui" line="1516"/>
        <location filename="../mainwindow.cpp" line="3039"/>
        <location filename="../mainwindow.cpp" line="3076"/>
        <location filename="../mainwindow.cpp" line="3178"/>
        <location filename="../mainwindow.cpp" line="3179"/>
        <source>Not installed</source>
        <translation>Non installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="785"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <location filename="../mainwindow.cpp" line="2574"/>
        <location filename="../mainwindow.cpp" line="3010"/>
        <location filename="../mainwindow.cpp" line="3077"/>
        <location filename="../mainwindow.cpp" line="3163"/>
        <source>Autoremovable</source>
        <translation>Autosupprimable</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <location filename="../mainwindow.ui" line="727"/>
        <location filename="../mainwindow.ui" line="855"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= Paquet pouvant être mis à jour. Une version plus récente est disponible dans le dépôt sélectionné.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <location filename="../mainwindow.ui" line="802"/>
        <location filename="../mainwindow.ui" line="1059"/>
        <source>Package Name</source>
        <translation>Nom du paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>MX Test Repo</source>
        <translation>Dépôt de test MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <location filename="../mainwindow.ui" line="807"/>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Repo Version</source>
        <translation>Version du dépôt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <location filename="../mainwindow.ui" line="812"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Installed Version</source>
        <translation>Version installée</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="837"/>
        <source>Debian Backports</source>
        <translation>Dépôt de rétroportages Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1447"/>
        <location filename="../mainwindow.ui" line="1451"/>
        <location filename="../mainwindow.cpp" line="115"/>
        <location filename="../mainwindow.cpp" line="116"/>
        <source>For all users</source>
        <translation>Pour tous•tes les utilisateurs•rices</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>For current user</source>
        <translation>Pour l’utilisateur•rice actuel•le</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1541"/>
        <source>Remote (repo):</source>
        <translation>Dépôt à distance (repo):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <location filename="../mainwindow.ui" line="1486"/>
        <location filename="../mainwindow.cpp" line="3021"/>
        <source>All apps</source>
        <translation>Toutes les applications</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1491"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>All runtimes</source>
        <translation>Tous les environnements d’exécution (runtimes)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1496"/>
        <location filename="../mainwindow.cpp" line="3033"/>
        <source>All available</source>
        <translation>Total disponible</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1501"/>
        <location filename="../mainwindow.cpp" line="3018"/>
        <source>Installed apps</source>
        <translation>Applications installées</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1506"/>
        <location filename="../mainwindow.cpp" line="3015"/>
        <source>Installed runtimes</source>
        <translation>Environnements d’exécution (runtimes) installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1511"/>
        <location filename="../mainwindow.cpp" line="3037"/>
        <location filename="../mainwindow.cpp" line="3171"/>
        <location filename="../mainwindow.cpp" line="3172"/>
        <source>All installed</source>
        <translation>Tous installés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1303"/>
        <source>Total items </source>
        <translation>Nombre de paquets au total</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1317"/>
        <source>Installed apps:</source>
        <translation>Applications installées:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1369"/>
        <source>Advanced</source>
        <translation>Avancé</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1398"/>
        <source>Total installed size:</source>
        <translation>Taille totale installée:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1412"/>
        <source>Remove unused runtimes</source>
        <translation>Suppression des environnements d’exécution (runtimes) inutilisés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1249"/>
        <source>Short Name</source>
        <translation>Abréviation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1254"/>
        <source>Full Package Name</source>
        <translation>Nom complet du paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1264"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1558"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <location filename="../mainwindow.cpp" line="2935"/>
        <source>Console Output</source>
        <translation>Données de la sortie de console</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1564"/>
        <source>Enter</source>
        <translation>Entrer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1574"/>
        <source>Respond here, or just press Enter</source>
        <translation>Répondez ici, ou appuyez sur Entrée</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1633"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3162"/>
        <location filename="../mainwindow.cpp" line="3168"/>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Install</source>
        <translation>Installer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1639"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Quit application</source>
        <translation>Quitter l’application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1667"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1699"/>
        <source>About this application</source>
        <translation>À propos de cette application</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1702"/>
        <source>About...</source>
        <translation>À propos ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1708"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1746"/>
        <source>Display help </source>
        <translation>Afficher l’aide </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1749"/>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1755"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1771"/>
        <source>Uninstall</source>
        <translation>Désinstaller</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1777"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>Uninstalling packages...</source>
        <translation>Désinstallation des paquets ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Exécution des opérations de pré-désinstallation ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Running post-uninstall operations...</source>
        <translation>Processus post-désinstallation en cours ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Refreshing sources...</source>
        <translation>Rafraîchissement des sources ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <location filename="../mainwindow.cpp" line="1297"/>
        <location filename="../mainwindow.cpp" line="1432"/>
        <location filename="../mainwindow.cpp" line="1601"/>
        <location filename="../mainwindow.cpp" line="1666"/>
        <location filename="../mainwindow.cpp" line="1981"/>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="2567"/>
        <location filename="../mainwindow.cpp" line="2586"/>
        <location filename="../mainwindow.cpp" line="2693"/>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="2805"/>
        <location filename="../mainwindow.cpp" line="2838"/>
        <location filename="../mainwindow.cpp" line="3271"/>
        <location filename="../mainwindow.cpp" line="3347"/>
        <location filename="../mainwindow.cpp" line="3377"/>
        <location filename="../mainwindow.cpp" line="3479"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Un problème a été rencontré lors de la mise à jour des sources. Certaines sources n’ont pas pu fournir de mises à jour. Pour plus d’informations, consultez: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Could not determine Debian version. Please select your version:</source>
        <translation>Impossible de déterminer la version de Debian. Veuillez sélectionner votre version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Debian Version</source>
        <translation>Version Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Please wait...</source>
        <translation>Veuillez patienter ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1113"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Vous allez utiliser le dépôt de test MX dont les paquets sont fournis uniquement à des fins de test. Ils peuvent potentiellement casser votre système, aussi nous vous suggérons d’en faire une copie de sauvegarde et d’installer ou de mettre à jour un seul paquet à la fois. N’hésitez pas à nous faire un retour via le forum afin que les paquets soient évalués avant d’être transférés dans les dépôts principaux.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1122"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Vous êtes sur le point d’utiliser le dépôt de rétroportage (Backports) de Debian. Il contient des paquets provenant de la prochaine version de Debian (appelée « testing ») qui ont été modifiés et recompilés pour être utilisés dans Debian « stable ». Par conséquent, ils n’ont pas pu faire l’objet de tests aussi poussés que pour les versions stables de Debian et de MX Linux et peuvent présenter des incompatibilités avec d’autres composants de Debian « stable ». À utiliser avec précaution!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1130"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux inclut ce dépôt de flatpaks par commodité pour les utilisateurs•rices, mais n’est pas responsable de son bon fonctionnement. Pour plus d’informations, consultez flatpaks dans le Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1138"/>
        <location filename="../mainwindow.cpp" line="3507"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1142"/>
        <source>Do not show this message again</source>
        <translation>Ne plus afficher ce message</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1246"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1262"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Les paquets suivants ont été sélectionnés. Cliquez sur Afficher les détails pour obtenir la liste des modifications.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1298"/>
        <location filename="../mainwindow.cpp" line="1433"/>
        <location filename="../mainwindow.cpp" line="1667"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internet est indisponible, le téléchargement de la liste des paquets est impossible</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1301"/>
        <source>Installing packages...</source>
        <translation>Installation des paquets ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1359"/>
        <source>Post-processing...</source>
        <translation>Post-traitement ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1391"/>
        <source>Pre-processing for </source>
        <translation>Pré-traitement pour </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1405"/>
        <source>Installing </source>
        <translation>Installation </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1412"/>
        <source>Post-processing for </source>
        <translation>Post-traitement pour </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1602"/>
        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
        <translation>Une erreur s’est produite lors du téléchargement ou de l’écriture du fichier: %1. Veuillez vérifier votre connexion internet et l’espace libre sur votre périphérique.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <source>Downloading package info...</source>
        <translation>Téléchargement des infos des paquets ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1982"/>
        <source>dpkg-query command returned an error. Please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>La commande dpkg-query a renvoyé une erreur. Veuillez exécuter « dpkg-query -W » dans un terminal et vérifier la réponse.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2122"/>
        <source>dpkg-query command returned an error, please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>La commande dpkg-query a renvoyé une erreur, veuillez exécuter «&#xa0;dpkg-query -W&#xa0;» dans le terminal et vérifier le résultat.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2243"/>
        <location filename="../mainwindow.cpp" line="2345"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <source>Package info</source>
        <translation>Informations sur le paquet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2260"/>
        <location filename="../mainwindow.cpp" line="3411"/>
        <source>More &amp;info...</source>
        <translation>Plus &amp;info ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2291"/>
        <source>Packages to be installed: </source>
        <translation>Paquets à installer: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <source>Done</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Processing finished successfully.</source>
        <translation>Processus achevé avec succès.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2568"/>
        <location filename="../mainwindow.cpp" line="2587"/>
        <location filename="../mainwindow.cpp" line="3272"/>
        <location filename="../mainwindow.cpp" line="3348"/>
        <location filename="../mainwindow.cpp" line="3378"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Un problème a été détecté pendant l’installation, veuillez examiner les données de sortie de la console.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2597"/>
        <source>About %1</source>
        <translation>À propos %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2598"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2600"/>
        <source>Package Installer for MX Linux</source>
        <translation>Installateur de paquets pour MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2602"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2603"/>
        <source>%1 License</source>
        <translation>%1 Licence</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2615"/>
        <source>%1 Help</source>
        <translation>%1 Aide</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2693"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Problème rencontré durant la désinstallation. Vérifiez la sortie.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Success</source>
        <translation>Installation réussie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Un problème a été rencontré lors de la désinstallation du programme</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2806"/>
        <location filename="../mainwindow.cpp" line="2839"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>Impossible de télécharger la liste des paquets. Veuillez vérifier vos sources APT.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2876"/>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak n’est pas installé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2877"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak n’est pas installé actuellement.
Voulez-vous l’installer?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak n’a pas été installé</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2939"/>
        <source>Needs re-login</source>
        <translation>Reconnexion requise</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2940"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Vous pourriez devoir vous déconnecter/reconnecter pour voir les paquets installés dans le menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <source>Mark keep</source>
        <translation>Marquer à conserver</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3162"/>
        <source>Upgrade</source>
        <translation>Mettre à niveau</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3300"/>
        <source>Quit?</source>
        <translation>Quitter?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3301"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Processus toujours en cours, quitter maintenant pourrait laisser le système en état d’instabilité .&lt;p&gt;&lt;b&gt;Êtes-vous sûr•e de vouloir quitter l’installateur de paquets MX?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Reinstall</source>
        <translation>Réinstaller</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3480"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Problème détecté lors de la dernière opération, veuillez examiner les données de la sortie de console.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3508"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Opération potentiellement dangereuse.
Veillez à bien vérifier la liste des paquets à supprimer.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="16"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Gérer les dépôts à distance Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Pour tous•tes les utilisateurs•rices</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Pour l’utilisateur•rice actuel•le</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>enter Flatpak remote URL</source>
        <translation>Entrez l’URL du dépôt à distance Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="38"/>
        <source>enter Flatpakref location to install app</source>
        <translation>Entrez l’emplacement Flatpakref pour installer l’application</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="40"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Ajouter ou supprimer dépôts à distance flatpak (dépôts), ou installer des applications via l’URL ou le chemin flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Remove remote</source>
        <translation>Supprimer dépôt à distance</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Add remote</source>
        <translation>Ajouter dépôt à distance</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Install app</source>
        <translation>Installer l’application</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="64"/>
        <source>Close</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>Ne peut être supprimé</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="82"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub est le principal dépôt à distance Flatpak et ne sera pas supprimé</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Error adding remote</source>
        <translation>Erreur durant l’ajout du dépôt à distance</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Le dépôt à distance n’a pas pu être ajouté - la commande a diagnostiqué une erreur. Vérifiez attentivement l’adresse du dépôt à distance et essayez à nouveau</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Success</source>
        <translation>Installation réussie</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Remote added successfully</source>
        <translation>Dépôt à distance ajouté avec succès</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Journal des modifications</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>Attention</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>La base de données dpkg/apt est verrouillée par un autre programme: %1
Fermez le programme ou attendez qu’il ait terminé son traitement et réessayez.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>MX Package Installer est un outil utilisé pour gérer les paquets de MX Linux.
    - installe des programmes populaires à partir de différentes sources
    - installe des programmes à partir du dépôt test de MX
    - installe des programmes à partir des rétroportages - backports - de Debian
    - installe des flatpaks</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>Ignorer le contrôle en ligne s’il signale à tort l’absence d’accès à l’internet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <location filename="../main.cpp" line="106"/>
        <source>Error</source>
        <translation>Erreur</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Vous êtes apparemment connecté en tant que root, veuillez vous déconnecter et vous connecter en tant qu’utilisateur•rice normal•e pour utiliser ce programme.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>You must run this program with admin access.</source>
        <translation>Vous devez exécuter ce programme avec un accès d’administrateur•rice.</translation>
    </message>
</context>
</TS>
